Struct l337_postgres::PostgresConnectionManager [−][src]
pub struct PostgresConnectionManager<T> where
T: 'static + MakeTlsConnect<Socket> + Clone + Send + Sync, { /* fields omitted */ }Expand description
A ManageConnection for tokio_postgres::Connections.
Implementations
impl<T> PostgresConnectionManager<T> where
T: 'static + MakeTlsConnect<Socket> + Clone + Send + Sync, [src]
impl<T> PostgresConnectionManager<T> where
T: 'static + MakeTlsConnect<Socket> + Clone + Send + Sync, [src]Trait Implementations
impl<T> Debug for PostgresConnectionManager<T> where
T: 'static + MakeTlsConnect<Socket> + Clone + Send + Sync, [src]
impl<T> Debug for PostgresConnectionManager<T> where
T: 'static + MakeTlsConnect<Socket> + Clone + Send + Sync, [src]impl<T> ManageConnection for PostgresConnectionManager<T> where
T: 'static + MakeTlsConnect<Socket> + Clone + Send + Sync,
T::Stream: Send + Sync,
T::TlsConnect: Send,
<T::TlsConnect as TlsConnect<Socket>>::Future: Send, [src]
impl<T> ManageConnection for PostgresConnectionManager<T> where
T: 'static + MakeTlsConnect<Socket> + Clone + Send + Sync,
T::Stream: Send + Sync,
T::TlsConnect: Send,
<T::TlsConnect as TlsConnect<Socket>>::Future: Send, [src]type Connection = AsyncConnection
type Connection = AsyncConnectionThe connection type this manager deals with.
fn connect<'life0, 'async_trait>(
&'life0 self
) -> Pin<Box<dyn Future<Output = Result<Self::Connection, Error<Self::Error>>> + Send + 'async_trait>> where
'life0: 'async_trait,
Self: 'async_trait, [src]
fn connect<'life0, 'async_trait>(
&'life0 self
) -> Pin<Box<dyn Future<Output = Result<Self::Connection, Error<Self::Error>>> + Send + 'async_trait>> where
'life0: 'async_trait,
Self: 'async_trait, [src]Attempts to create a new connection. Read more
fn is_valid<'life0, 'life1, 'async_trait>(
&'life0 self,
conn: &'life1 mut Self::Connection
) -> Pin<Box<dyn Future<Output = Result<(), Error<Self::Error>>> + Send + 'async_trait>> where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait, [src]
fn is_valid<'life0, 'life1, 'async_trait>(
&'life0 self,
conn: &'life1 mut Self::Connection
) -> Pin<Box<dyn Future<Output = Result<(), Error<Self::Error>>> + Send + 'async_trait>> where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait, [src]Determines if the connection is still connected to the database. Read more
fn has_broken(&self, conn: &mut Self::Connection) -> bool[src]
fn has_broken(&self, conn: &mut Self::Connection) -> bool[src]Quick check to determine if the connection has broken